/********************************************************************************************************
Macro Name:   normDesign.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
     This program calculates the power/type I error rates based on simulated normal studies but
     not using any prior information

**** Needed Macro Variables;
    (1) nSamp           = <integer> number of MCMC samples
    (2) gamma           = <double> lower bound for posterior probability decision rule
    (3) delta           = <double> non-inferiority margin
    (4) dsIn            = <libname.dataset> dataset containing simulation studies for analysis
    (5) dsOut           = <libname.dataset> dataset containing empirical power/type one error rates
*********************************************************************************************************/

%macro NormDesign(nSamp=10000,gamma=0.95,delta=0.20,dsIn=simStudy,dsOut=simStudyResults);

proc IML;
delta = &delta.;
gamma = &gamma.;
nSamp = &nSamp.;

 use &dsIn.;
 read all var _all_;

 mu1  = J(nSamp,1,0);
 mu2  = J(nSamp,1,0);
 sig2 = J(nSamp,2,0);
 
 studyRepNum = max(studyRep);

 PostProb = J(studyRepNum,1,0);

 do j = 1 to studyRepNum;
  call randgen(sig2,'gamma',(Ntot[j]-2)/2,2/(Yt_SSE[j]+Yc_SSE[j])); sig2 = 1/sig2;
  call randgen(mu1,'normal',Yt_mean[j],sqrt(sig2/Nt[j])); 
  call randgen(mu2,'normal',Yc_mean[j],sqrt(sig2/Nc[j])); 

   diff = mu1-mu2;

   indicator = (diff < delta)[+]/nSamp;
   PostProb[j] = (indicator > gamma);
 end;

 rejRate = PostProb[+]/studyRepNum;

 dat = mu_t[1]||mu_c[1]||nt[1]||nc[1]||rejRate;

 create &dsOut. from dat[c={"mu_t" "mu_c" "nt" "nc" "RejRate" }];
  append from dat;
 close &dsOut.;

quit;;

data &dsOut.;
 set &dsOut.;
  label RejRate = 'Empirical Null Hypothesis Rejection Rate';
run;

%mend NormDesign;