/********************************************************************************************************
Macro Name:   simNorm.sas
Author:       Matthew Psioda
Affiliation:  Department of Biostatistics, University of North Carolina at Chapel Hill
    
**** Program Summary:
     This program simulates multiple studies from the relevant normal design. 
**** Needed Macro Variables;
    (1) mu_t          = <double> mean of the treatment group
    (2) nt            = <integer> number of subjects in treatment group
    (3) mu_c          = <double> mean of the control group
    (4) nc            = <integer> number of subjects in control group
	(5) sd            = <double|RANDOM> standard deviation for both groups or RANDOM to specify a gamma distribution for precision parameter
    (6) studyRepNum   = <integer> number of studies to simulate
    (7) dsOut         = <libname.dataset> dataset containing all simulation studies
    (8) precShapeParm = <double> precision parameter shape parameter (only needs a value if sd=RANDOM)
    (9) precRateParm  = <double> precision parameter rate parameter (only needs a value if sd=RANDOM)
*********************************************************************************************************/

%macro simNorm(mu_t,mu_c,sd,nt,nc,studyRepNum=100,dsOut=simStudy,precShapeParm=0,precRateParm=0);

 proc IML;
  
  studyRepNum = &studyRepNum.;
  mu          = {&mu_t. &mu_c.};
  nGrp        = {&nt. &nc.};

%if &SD ^= RANDOM %then %do;  
  sd = J(1,studyRepNum,&sd.);
%end;
%else %do;
  sd = J(1,studyRepNum,0);
  call randgen(sd,'gamma',&precShapeParm.,1/(&precRateParm.));
  sd = sqrt(1/sd);
%end;
  
  Yt = J(nGrp[1],studyRepNum,0); tempt =  J(nGrp[1],1,0);
  Yc = J(nGrp[2],studyRepNum,0); tempc =  J(nGrp[2],1,0);
  
  do k = 1 to studyRepNum;
     call randgen(tempt,'normal',mu[1],sd[k]); Yt[,k] = tempt;
     call randgen(tempc,'normal',mu[2],sd[k]); Yc[,k] = tempc;	 
  end;
  
  Ytmean = t(mean(Yt));
  YtSSE  = t(var(Yt))*(nGrp[1]-1);
  
  Ycmean = t(mean(Yc));
  YcSSE  = t(var(Yc))*(nGrp[2]-1); 	
  		
	
  N = J(studyRepNum,1,nGrp[1])||J(studyRepNum,1,nGrp[2]);




  Z = t(do(1,studyRepNum,1));
  mu = repeat(mu,studyRepNum,1);

  dat = Z||mu||t(sd)||Ytmean||YtSSE||Ycmean||YcSSE||N||N[,+];

  create &dsOut. from dat[c={"studyRep" "mu_t" "mu_c" "sd" "Yt_mean" "Yt_SSE" "Yc_mean" "Yc_SSE" "Nt" "Nc" "Ntot"}];
   append from dat;
  close &dsOut.;


 quit;

%mend;